@@ -1,11 +1,12 @@
 from typing import Optional, Union, Any
 from collections.abc import Iterable
+from abc import ABC
 
 from ...model import Recipe
-from ..base import ExporterBase
+from ..base import TextExporterBase
 
 
-class TemplateExporterBase(ExporterBase):
+class TemplateExporterBase(TextExporterBase, ABC):
     def __init__(self, template: str, variables: Optional[dict[str, Any]] = None):
         self.template = template
         if variables is None:
