@@ -28,9 +28,8 @@ class Exporter(TextExporterBaseAtomic):
     name = "yml"
     ext = "yml"
 
-    @staticmethod
-    def export_stream(recipe: Recipe, stream: IO[str]) -> None:
-        serialized = asdict(recipe, dict_factory=OrderedDict)  # type: ignore
+    def export_stream_single(self, recipe: Recipe, stream: IO[str]) -> None:
+        serialized = asdict(recipe, dict_factory=OrderedDict)
 
         def represent_fraction(dumper: yaml.Dumper, data: Fraction) -> yaml.ScalarNode:
             if data.denominator == 1:
